@@ -1,7 +1,7 @@
 package Complete::Perl;
 
-our $DATE = '2015-12-08'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-10-18'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,19 +16,55 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
                        complete_perl_version
+                       complete_perl_builtin_function
+                       complete_perl_builtin_symbol
                );
 
-# TODO: complete_lexical, though probably you should just use
-# complete_array_elem(array => [keys %{ lexicals() }]) (see L<lexicals>)
+$SPEC{complete_perl_builtin_function} = {
+    v => 1.1,
+    description => <<'_',
 
-# TODO: complete_function(package => ...)
+Currently using `@Functions` from <pm:B::Keywords>.
 
-# TODO: complete_global_variable(package => ...) # can complete
-# array/hash/scalar, can accept sigil or not
+_
+    args => {
+        %arg_word,
+    },
+    result_naked => 1,
+};
+sub complete_perl_builtin_function {
+    require B::Keywords;
+    require Complete::Util;
 
-# TODO: complete_method()
+    my %args = @_;
+    Complete::Util::complete_array_elem(
+        word => $args{word},
+        array => \@B::Keywords::Functions,
+    );
+}
 
-# TODO: complete_keyword()
+$SPEC{complete_perl_builtin_symbol} = {
+    v => 1.1,
+    description => <<'_',
+
+Currently using `@Symbols` from <pm:B::Keywords>.
+
+_
+    args => {
+        %arg_word,
+    },
+    result_naked => 1,
+};
+sub complete_perl_builtin_symbol {
+    require B::Keywords;
+    require Complete::Util;
+
+    my %args = @_;
+    Complete::Util::complete_array_elem(
+        word => $args{word},
+        array => \@B::Keywords::Symbols,
+    );
+}
 
 $SPEC{complete_perl_version} = {
     v => 1.1,
@@ -54,7 +90,7 @@ and if none is found will try with.
 _
         },
     },
-
+    result_naked => 1,
 };
 sub complete_perl_version {
     require Complete::Util;
@@ -121,18 +157,54 @@ Complete::Perl - Complete various Perl entities
 
 =head1 VERSION
 
-This document describes version 0.03 of Complete::Perl (from Perl distribution Complete-Perl), released on 2015-12-08.
+This document describes version 0.04 of Complete::Perl (from Perl distribution Complete-Perl), released on 2016-10-18.
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-Not yet implemented, land grab :)
-
 =head1 FUNCTIONS
 
 
-=head2 complete_perl_version(%args) -> [status, msg, result, meta]
+=head2 complete_perl_builtin_function(%args) -> any
+
+Currently using C<@Functions> from L<B::Keywords>.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<word>* => I<str> (default: "")
+
+Word to complete.
+
+=back
+
+Return value:  (any)
+
+
+=head2 complete_perl_builtin_symbol(%args) -> any
+
+Currently using C<@Symbols> from L<B::Keywords>.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<word>* => I<str> (default: "")
+
+Word to complete.
+
+=back
+
+Return value:  (any)
+
+
+=head2 complete_perl_version(%args) -> any
 
 This function is not exported by default, but exportable.
 
@@ -159,17 +231,24 @@ Word to complete.
 
 =back
 
-Returns an enveloped result (an array).
-
-First element (status) is an integer containing HTTP status code
-(200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
-
 Return value:  (any)
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Complete-Perl>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Perl>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Perl>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 SEE ALSO
 
 L<Complete>
@@ -179,29 +258,13 @@ L<Complete::Module>
 L<Reply> (which has plugins to complete global variables, user-defined
 functions, lexicals, methods, packages, and so on).
 
-=head1 HOMEPAGE
-
-Please visit the project's homepage at L<https://metacpan.org/release/Complete-Perl>.
-
-=head1 SOURCE
-
-Source repository is at L<https://github.com/perlancar/perl-Complete-Perl>.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Complete-Perl>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
